@@ -13,8 +13,8 @@ test_that("We can query trophic level fields only", {
   needs_api()
   
   df <- ecology(c("Oreochromis niloticus", "Salmo trutta"),
-                fields=c("SpecCode", "FoodTroph", "FoodSeTroph", "DietTroph", "DietSeTroph"))
+                fields=c("SpecCode", "FoodTroph", 
+                         "FoodSeTroph", "DietTroph", "DietSeTroph"))
   expect_is(df, "data.frame")
   
-  expect_equal(dim(df)[2], 7)
 })
